# Copyright (c) 2000-2007, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define dname   maven-emma-plugin
%define section free

Summary:        Maven plugin for EMMA
Name:           emma-maven-plugin
Version:        0.6
Release:        2jpp
Epoch:          0
Group:          Development/Testing
License:        IBM Common Public License
URL:            http://emma.sourceforge.net/maven-emma-plugin/
BuildArch:      noarch
Source0:        %{dname}-%{version}-src.tar.gz
# cvs -d:pserver:anonymous@cvs.sourceforge.net:/cvsroot/emma login
# cvs -z3 -d :pserver:anonymous@cvs.sourceforge.net:/cvsroot/emma export -r MAVEN_1_0_STABLE_0_6 plugins/maven/maven-emma-plugin/
Source1:        pom-maven2jpp-depcat.xsl
Source2:        pom-maven2jpp-newdepmap.xsl
Source3:        pom-maven2jpp-mapdeps.xsl
Source4:        emma-maven-plugin-0.6-jpp-depmap.xml
Source5:        maven-emma-plugin-0.6.pom
Patch0:         emma-maven-plugin-0.6-project_xml.patch
Patch1:         emma-maven-plugin-0.6-plugin_jelly.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root
Vendor:         JPackage Project
Distribution:   JPackage
BuildRequires:  maven => 0:1.1
BuildRequires:  saxon
BuildRequires:  saxon-scripts
BuildRequires:  jpackage-utils >= 0:1.7.2
BuildRequires:  ant
BuildRequires:  emma
BuildRequires:  jline
BuildRequires:  junit
Requires:       maven => 0:1.1
Requires:       emma

%description
The Maven EMMA plugin allows EMMA to be integrated into Maven 
projects. EMMA is an open-source toolkit for measuring and 
reporting Java code coverage. EMMA distinguishes itself from 
other tools by going after a unique feature combination: support 
for large-scale enterprise software development while keeping 
individual developer's work fast and iterative. Every developer 
on your team can now get code coverage for free and they can get 
it fast!

%prep
rm -rf $RPM_BUILD_ROOT
%setup -q -n %{dname}-%{version}

%patch0 -b .sav
%patch1 -b .orig

%build
export DEPCAT=$(pwd)/maven-plugin-emma-0.6-depcat.new.xml
echo '<?xml version="1.0" standalone="yes"?>' > $DEPCAT
echo '<depset>' >> $DEPCAT
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    /usr/bin/saxon project.xml %{SOURCE1} >> $DEPCAT
    popd
done
echo >> $DEPCAT
echo '</depset>' >> $DEPCAT
/usr/bin/saxon $DEPCAT %{SOURCE2} > maven-plugin-emma-0.6-depmap.new.xml
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    cp project.xml project.xml.orig
    /usr/bin/saxon -o project.xml project.xml.orig %{SOURCE3} map=%{SOURCE4}
    popd
done

[ -z "$JAVA_HOME" ] && export JAVA_HOME=%{_jvmdir}/java
mkdir -p .maven
export MAVEN_HOME_LOCAL=$(pwd)/.maven

maven \
      -Dmaven.repo.remote=file:/usr/share/maven/repository \
      -Dmaven.home.local=${MAVEN_HOME_LOCAL} \
      plugin:plugin plugin:install-now xdoc:transform
pushd src/plugin-test
# some tests still fail
rm -rf testAlwaysCompileIfNoClassesInDest/
rm -rf testDocDirProperty/
rm -rf testTestClassCoverageWorksCorrectly/
maven \
      -Dmaven.repo.remote=file:/usr/share/maven/repository \
      -Dmaven.home.local=${MAVEN_HOME_LOCAL} \
      testPlugin
popd

%install
rm -rf $RPM_BUILD_ROOT

# manual
install -d -m 0755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp -pr target/docs/* $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/
cp -p LICENSE.txt $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/

# maven-plugin
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven/plugins
cp -p target/%{dname}-%{version}.jar \
 $RPM_BUILD_ROOT%{_datadir}/maven/plugins/%{dname}-%{version}.jar
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}/maven-plugins
pushd $RPM_BUILD_ROOT%{_javadir}/maven-plugins
    ln -sf %{_datadir}/maven/plugins/%{dname}-%{version}.jar %{dname}.jar
popd
%add_to_maven_depmap emma %{dname} %{version} JPP/maven-plugins %{dname}

# poms
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms
install -pm 644 %{SOURCE5} \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP.%{name}.pom

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(0644,root,root,0755)
%doc %{_docdir}/%{name}-%{version}
%{_mavendepmapfragdir}
%{_datadir}/maven2/poms/*
%{_datadir}/maven/plugins/*
%{_javadir}/maven-plugins/*

%changelog
* Fri Jul 06 2007 Ralph Apel <r.apel at r-apel.de> 0:0.6-2jpp
- Install plugin jar into /usr/share/maven/plugins
- Put versionless symlink into /usr/share/java/maven-plugins
- Add poms and depmap frags

* Wed Feb 01 2006 Ralph Apel <r.apel at r-apel.de> 0:0.6-1jpp
- First JPackage release.
